# stuvus Erstsemestereinführung Website

## Contentpflege
Sämtlicher statischer Content außerhalb des Kalenders wird direkt in `src/index.html` bearbeitet.
Die Termine des Kalendars und die Informationen über Fachgruppen und Studiengänge werden in `data/data.json` gepflegt.

Es ist möglich, auch ohne Git-Kenntnisse den Inhalt zu bearbeiten. Gitlab bietet dazu eine Web IDE an. Diese lässt mit einem Klick auf Edit > Web IDE öffnen.


### Events
Es existieren zweierlei Typen von Events. Events welche zentral für alle Studiengänge angeboten werden und Events welche Fachgruppen spezifisch sind.
Alle Events werden in der Datei `data/data.json` gesammelt. Zentrale Events dabei in der Liste `centralEvents` und Events der Fachgruppen in der Liste `events` im jeweiligen Fachgruppen Objekt.
Folgendes Beispiel zeigt schematisch den Aufbau solch eines Events.
````js
{
  "id": "MdM", // Nur notwendig, wenn das Event von anderen Events "eliminiert" werden kann
  "day": 7, // Tag im Monat
  "startTime": "11:30",
  "endTime": "12:30",
  "title": { // Sollte keine Übersetzung verfügbar oder notwendig sein kann auch direkt ein String verwendet werden. e.g. `"title": "Markt der Möglichkeiten"`
    "de": "Markt der Möglichkeiten",
    "en": "Fair of Student Possibilities"
  },
  "description": { // In der Description kann vollwertiges HTML verwendet werden.
    "de": "<p>Die Avete ist die offizielle Begrüßungs- und Informationsv .... 1: <a href=\"https://www.youtube.com/watch?v=PPht25hnYNQ\">https://www.youtube.com/watch?v=PPht25hnYNQ</a></p>",
    "en": "<p>The Avete Academici is the official welcome and informat.. rding from 2021: <a href=\"https://www.youtube.com/watch?v=PPht25hnYNQ\">https://www.youtube.com/watch?v=PPht25hnYNQ</a></p>"
  },
  "locationShort": "Liederhalle, Stadtmitte", // Ort welche in der Kalendarübersicht angezeigt wird
  "location": "Foyer des 9er Gebäudes", // Ausführlich Beschreibung des Ortes. Wird in der Detailansicht angezeigt. Wenn nicht gesetzt Rückfall zu `locationShort`
  "type": "social", // social, info, party oder sport
  "registrationRequired": false,
  "important": true, // Bei true wird das Event als besonders wichtig angezeigt
  // Nur für zentrale Events relevant
  "campusExclusive": "Stadtmitte", // Wenn dieses Attribut gesetzt ist wird das Event nur angezeigt, wenn die ausgewählen Studiengänge ihren Fokus auf diesem Campus besitzen
  
  // Nur für Fachgruppen Events relevant
  "eliminates": "central-campusrally-vaihingen", // Wenn dieses Attribut gesetzt ist wird die zentrale Veranstaltung mit der angegebenden id nicht im Kalendar angezeigt. Somit können z.B. Fachgruppenrallies priorisiert werden
  "studyPrograms": [ // Wenn gesetzt, wird die Veranstaltung nur angezeigt, wenn einer der folgeden Studiengänge studiert wird.
        "Maschinenbau",
        "Erneuerbare Energien"
   ]
}

````
Zusätzlich muss jedes Jahr der Zeitraum der ESE in der Datei `src/main.js` abgeändert werden. Dafür die Daten in der Variable `calendarOptions` anpassen.
### Fachgruppen Informationen und Studiengänge
Genauso wie Events werden Fachgruppen in der Datei `data/data.json` in der Liste `fachgruppen` gesammelt.
Das Beispiel der Fachgruppe Mathematik zeigt schematisch den Aufbau.
````js
{
  "name": "Mathematik",
  "address": "NWZ 2, 8.Stock, Raum 8.326\nPfaffenwaldring 57, 70569 Stuttgart",
  "email": "fachgruppe@mathematik.uni-stuttgart.de",
  "web": "www.mathe.stuvus.uni-stuttgart.de",
  "telephone": "0711/685 65341",
  "welcomeText": {
    "de": "<p>Wir, die Fachgruppe Mathematik, begrüßen euch Erstsemester herzlich ...</p>",
    "en": "<p>We, the Mathematics student group (Fachgruppe), welcome you first-y...</p>"
  },
  "campus": "Vaihingen",
  "studyPrograms": [
    "Mathematik" // Liste aller zugeortnerter Studiengänge
  ],
  "events": [
    //... Der Aufbau von Events wurde bereits im vorherigen Abschnitt beschreiben
  ]
}
````

### Infotexte
Beim Anpassen der Infotexte muss darauf geachtet werden, dass die jeweilige englische Übersetzung im `text-en` Attribut angegeben wird.
Wenn als Sprache Englisch eingestellt ist, wir der Inhalt des Attributes als alternativer Inhalt des Elements verwendet.~~~~
### FAQ
Neue FAQ-Einträge lassen sich durch Hinzufügen eines `faq-item` Elements anlegen.
Damit der Eintrag in sowohl Deutsch als auch in Englisch erscheint muss ein `faq-item` Element in sowohl dem `<template lang-only="de">` als auch dem `<template lang-only="en">` erstellt werden.
````html
<template lang-only="de">
    ....
    <faq-item question="Sprachenzentrum"> <!-- das question attribut enhält die Überschrift -->
        <p>Das Sprachenzentrum der Universität Stuttgart hat ein
            breites Kursangebot an Fach- und Fremdsprachen und bietet auch sonst viele interessante
            Dinge an. Das Kursangebot, Beratungsmöglichkeiten, mehr Informationen und Öffnungszeiten
            finden sich ihr <a href="https://www.sz.uni-stuttgart.de/" target="_blank">hier</a>. <!-- Mit target="_blank" wird der link in einem neuen Tab geöffnet -->
        </p>
        <p>
            Das ist ein zweiter Absatz
        </p>
    </faq-item>
    ....
</template>
<template lang-only="en">
    ....
    <faq-item question="Language Centre">
        <p>The Language Centre of the Universität of Stuttgart offers a wide range of courses in
            specialist and foreign languages and also offers many other interesting things. You can
            find the range of courses on offer, advice, more information and opening hours <a
                    href="https://www.sz.uni-stuttgart.de/" target="_blank">here</a>.
        </p>
        <p>
            This is a second paragraph
        </p>
    </faq-item>
    ...
</template>
````