import './main.css'
import 'bulma/css/bulma.css'
import data from '../data/data.json'

let isGerman = navigator.language.indexOf('de') !== -1;
const localStorageIsGerman = localStorage.getItem("localeGerman")
if (localStorageIsGerman !== null) {
    isGerman = localStorageIsGerman === "true"
}

document.getElementById("language-toggle").addEventListener("click", () => {
    localStorage.setItem("localeGerman", (!isGerman).toString())
    window.location.reload();
})

const translate = translations => typeof translations == "string" ? translations : (translations ? (isGerman ? translations.de : translations.en || translations.de) : null)
if (!isGerman) {
    for (const el of document.querySelectorAll("[text-en]")) {
        el.innerHTML = el.attributes["text-en"].value
    }
}

for (const el of document.querySelectorAll("[lang-only]")) {
    const langFilter = el.attributes["lang-only"]?.value;
    if ((langFilter === "de") === isGerman) {
        el.parentElement.appendChild(el.content.cloneNode(true))
    }
}

const allStudyPrograms = []
data.fachgruppen.forEach(fg => allStudyPrograms.push(...fg.studyPrograms))
allStudyPrograms.sort()

const calendarOptions = {
    year: 2024,
    month: 10,
    firstDay: 7,
    lastDay: 13,
    startHour: 9,
    endHour: 21,
}


function setupEventModal() {
    const eventModalEl = document.getElementById("event-modal")
    const eventModalTitleEl = document.getElementById("event-modal-title")
    const eventModalTimesEl = document.getElementById("event-modal-times")
    const eventModalLocationEl = document.getElementById("event-modal-location")
    const eventModalDescriptionEventEl = document.getElementById("event-modal-description")

    function closeModal() {
        eventModalEl.classList.remove("is-active")
    }


    function closeModalAndNavigate() {
        let scrollPosition = window.scrollY
        closeModal()
        window.location.href = '#'
        window.scrollTo({top: scrollPosition})
    }

    document.querySelector(".modal-close").addEventListener("click", closeModalAndNavigate)
    document.querySelector(".modal-background").addEventListener("click", closeModalAndNavigate)

    function onNavigation() {
        function getEvent() {
            const hash = window.location.hash.substring(1)
            if (!hash) return
            const hashParts = decodeURIComponent(hash).split("&").map(decodeURIComponent)
            if (hashParts.length !== 3) return
            const [organizer, title, location] = hashParts
            let organiserEvents
            if (organizer === "central") {
                organiserEvents = data.centralEvents
            } else {
                const fg = data.fachgruppen.find(fg => fg.name === organizer)
                if (!fg) return
                organiserEvents = fg.events
            }
            return organiserEvents.find(event => (event.title.de || event.title) === title && event.locationShort === location)
        }

        const event = getEvent()
        if (!event) {
            closeModal()
            return
        }
        eventModalEl.classList.add("is-active")
        eventModalTitleEl.innerHTML = translate(event.title)
        eventModalLocationEl.innerHTML = event.location || event.locationShort || ""
        eventModalTimesEl.innerHTML = `${new Date(calendarOptions.year, calendarOptions.month, event.day).toLocaleDateString(undefined, {
            weekday: "long",
            day: "2-digit",
            month: "2-digit"
        })} &middot ${event.startTime} - ${event.endTime}`
        eventModalDescriptionEventEl.innerHTML = translate(event.description) || ""
        /*
        if(event.mapLink) {
            const mapIframe = document.createElement("iframe")
            mapIframe.src = event.mapLink
            mapIframe.height = "400"
            eventModalDescriptionEventEl.append(mapIframe)
        }
         */
    }


    window.addEventListener("hashchange", onNavigation)
    onNavigation();
}

setupEventModal()

function setupStudyProgramDropdown() {
    let dropdownOpen = false
    let isLehramt = false
    let activeStudyProgramEls = []
    let maxActiveStudyPrograms = 1

    const dropdownButtonEl = document.getElementById("studyProgram-dropdown-button")
    const dropdownSelectionEl = document.getElementById("studyProgram-dropdown-selection")
    const dropdownMenuEl = document.getElementById("studyProgram-dropdown-menu")
    const dropdownContentEl = document.getElementById("studyProgram-dropdown-content")
    const dropdownSearchEl = document.getElementById("studyProgram-dropdown-search")
    const dropdownLehramtCheckboxEl = document.getElementById("studyProgram-dropdown-lehramt-checkbox")
    const dropdownLehramtHintEl = document.getElementById("studyProgram-dropdown-lehramt-hint")

    const preSelectedStudyPrograms = JSON.parse(localStorage.getItem("studyPrograms")) || []
    if (preSelectedStudyPrograms.indexOf("Lehramt") !== -1) {
        dropdownLehramtCheckboxEl.checked = true
    }

    buildCalendar(preSelectedStudyPrograms)

    function openDropdown() {
        dropdownOpen = true
        dropdownMenuEl.style.display = "block"
    }

    function closeDropdown() {
        dropdownOpen = false
        dropdownMenuEl.style.display = "none"
    }

    dropdownButtonEl.addEventListener("click", () => {
        if (dropdownOpen) {
            closeDropdown()
        } else {
            openDropdown()
        }
    })

    const onLehramtCheckboxChange = () => {
        isLehramt = dropdownLehramtCheckboxEl.checked;
        dropdownLehramtHintEl.style.display = isLehramt ? "flex" : "none"
        maxActiveStudyPrograms = isLehramt ? 2 : 1
        while (activeStudyProgramEls.length > 1) {
            activeStudyProgramEls[0].classList.remove("is-active")
            activeStudyProgramEls.shift()
        }
        if (activeStudyProgramEls.length === 1) {
            const studyProgram = activeStudyProgramEls[0].innerHTML
            dropdownSelectionEl.innerHTML = studyProgram
            buildCalendar([studyProgram])
            localStorage.setItem("studyPrograms", JSON.stringify([studyProgram]))
        }
    }
    dropdownLehramtCheckboxEl.addEventListener("change", onLehramtCheckboxChange);
    onLehramtCheckboxChange();
    const renderStudyPrograms = () => {
        if (activeStudyProgramEls.length === 0) return;
        dropdownSelectionEl.innerHTML = activeStudyProgramEls.map(el => el.innerHTML).join(" & ") + (isLehramt ? " (Lehramt)" : "")
    }

    for (const studyProgram of allStudyPrograms) {
        const studyProgramEl = document.createElement("button")
        studyProgramEl.classList.add("dropdown-item")
        studyProgramEl.classList.add("studyProgram-dropdown-item")
        studyProgramEl.innerHTML = studyProgram
        if (preSelectedStudyPrograms.indexOf(studyProgram) !== -1) {
            studyProgramEl.classList.add("is-active")
            activeStudyProgramEls.push(studyProgramEl)
        }
        studyProgramEl.addEventListener("click", () => {
            if (activeStudyProgramEls.includes(studyProgramEl)) {
                return
            }
            activeStudyProgramEls.push(studyProgramEl)
            studyProgramEl.classList.add("is-active")
            if (activeStudyProgramEls.length > maxActiveStudyPrograms) {
                activeStudyProgramEls[0].classList.remove("is-active")
                activeStudyProgramEls.shift()
            }

            const setStudyProgram = (studyPrograms) => {
                localStorage.setItem("studyPrograms", JSON.stringify(studyPrograms))
                closeDropdown()
                buildCalendar(studyPrograms)
            }
            renderStudyPrograms()

            if (!isLehramt) {
                setStudyProgram([studyProgram])
            } else {
                if (activeStudyProgramEls.length > 1) {
                    setStudyProgram([...activeStudyProgramEls.map(el => el.innerHTML), "Lehramt"])
                }
            }
        })
        dropdownContentEl.appendChild(studyProgramEl)
    }

    renderStudyPrograms()


    dropdownSearchEl.addEventListener("input", () => {
        const searchValue = dropdownSearchEl.value.toLowerCase()
        dropdownContentEl.querySelectorAll(".studyProgram-dropdown-item").forEach(studyProgramEl => {
            studyProgramEl.style.display = (searchValue.length === 0 || studyProgramEl.innerHTML.toLowerCase().includes(searchValue)) ? "block" : "none"
        })
    })
}

const calendarEl = document.getElementById("calendar")

const renderCalendarScrollFade = () => {
    if (calendarEl.offsetWidth + calendarEl.scrollLeft > calendarEl.scrollWidth - 60) {
        calendarEl.classList.remove("fade-right")
    } else {
        calendarEl.classList.add("fade-right")
    }
}
calendarEl.addEventListener("scroll", renderCalendarScrollFade)
setTimeout(renderCalendarScrollFade, 10)

function buildCalendar(selectedStudyPrograms = []) {
    const timetableEl = document.querySelector(".timetable")
    if (selectedStudyPrograms.length === 0) {
        timetableEl.classList.add("not-chosen")
        timetableEl.classList.remove("chosen")
    } else {
        timetableEl.classList.remove("not-chosen")
        timetableEl.classList.add("chosen")
    }
    const typeSvgs = {
        "sport": "<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 512 512\"><!--!Font Awesome Free 6.6.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2024 Fonticons, Inc.--><path fill=\"currentColor\" d=\"M417.3 360.1l-71.6-4.8c-5.2-.3-10.3 1.1-14.5 4.2s-7.2 7.4-8.4 12.5l-17.6 69.6C289.5 445.8 273 448 256 448s-33.5-2.2-49.2-6.4L189.2 372c-1.3-5-4.3-9.4-8.4-12.5s-9.3-4.5-14.5-4.2l-71.6 4.8c-17.6-27.2-28.5-59.2-30.4-93.6L125 228.3c4.4-2.8 7.6-7 9.2-11.9s1.4-10.2-.5-15l-26.7-66.6C128 109.2 155.3 89 186.7 76.9l55.2 46c4 3.3 9 5.1 14.1 5.1s10.2-1.8 14.1-5.1l55.2-46c31.3 12.1 58.7 32.3 79.6 57.9l-26.7 66.6c-1.9 4.8-2.1 10.1-.5 15s4.9 9.1 9.2 11.9l60.7 38.2c-1.9 34.4-12.8 66.4-30.4 93.6zM256 512A256 256 0 1 0 256 0a256 256 0 1 0 0 512zm14.1-325.7c-8.4-6.1-19.8-6.1-28.2 0L194 221c-8.4 6.1-11.9 16.9-8.7 26.8l18.3 56.3c3.2 9.9 12.4 16.6 22.8 16.6l59.2 0c10.4 0 19.6-6.7 22.8-16.6l18.3-56.3c3.2-9.9-.3-20.7-8.7-26.8l-47.9-34.8z\"/></svg>",
        "party": "<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 576 512\"><!--!Font Awesome Free 6.6.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2024 Fonticons, Inc.--><path fill=\"currentColor\" d=\"M488.2 59.1C478.1 99.6 441.7 128 400 128s-78.1-28.4-88.2-68.9L303 24.2C298.8 7.1 281.4-3.3 264.2 1S236.7 22.6 241 39.8l8.7 34.9c11 44 40.2 79.6 78.3 99.6L328 480c0 17.7 14.3 32 32 32s32-14.3 32-32l0-128 16 0 0 128c0 17.7 14.3 32 32 32s32-14.3 32-32l0-305.7c38.1-20 67.3-55.6 78.3-99.6L559 39.8c4.3-17.1-6.1-34.5-23.3-38.8S501.2 7.1 497 24.2l-8.7 34.9zM400 96a48 48 0 1 0 0-96 48 48 0 1 0 0 96zM80 96A48 48 0 1 0 80 0a48 48 0 1 0 0 96zm-8 32c-35.3 0-64 28.7-64 64l0 96 0 .6L8 480c0 17.7 14.3 32 32 32s32-14.3 32-32l0-128 16 0 0 128c0 17.7 14.3 32 32 32s32-14.3 32-32l0-227.3 13 20.5c5.9 9.2 16.1 14.9 27 14.9l48 0c17.7 0 32-14.3 32-32s-14.3-32-32-32l-30.4 0-37.4-58.9C157.6 142 132.1 128 104.7 128L72 128z\"/></svg>",
        "info": "<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 640 512\"><!--!Font Awesome Free 6.6.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2024 Fonticons, Inc.--><path fill=\"currentColor\" d=\"M160 64c0-35.3 28.7-64 64-64L576 0c35.3 0 64 28.7 64 64l0 288c0 35.3-28.7 64-64 64l-239.2 0c-11.8-25.5-29.9-47.5-52.4-64l99.6 0 0-32c0-17.7 14.3-32 32-32l64 0c17.7 0 32 14.3 32 32l0 32 64 0 0-288L224 64l0 49.1C205.2 102.2 183.3 96 160 96l0-32zm0 64a96 96 0 1 1 0 192 96 96 0 1 1 0-192zM133.3 352l53.3 0C260.3 352 320 411.7 320 485.3c0 14.7-11.9 26.7-26.7 26.7L26.7 512C11.9 512 0 500.1 0 485.3C0 411.7 59.7 352 133.3 352z\"/></svg>",
        "social": "<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 640 512\"><!--!Font Awesome Free 6.6.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2024 Fonticons, Inc.--><path fill=\"currentColor\" d=\"M144 0a80 80 0 1 1 0 160A80 80 0 1 1 144 0zM512 0a80 80 0 1 1 0 160A80 80 0 1 1 512 0zM0 298.7C0 239.8 47.8 192 106.7 192l42.7 0c15.9 0 31 3.5 44.6 9.7c-1.3 7.2-1.9 14.7-1.9 22.3c0 38.2 16.8 72.5 43.3 96c-.2 0-.4 0-.7 0L21.3 320C9.6 320 0 310.4 0 298.7zM405.3 320c-.2 0-.4 0-.7 0c26.6-23.5 43.3-57.8 43.3-96c0-7.6-.7-15-1.9-22.3c13.6-6.3 28.7-9.7 44.6-9.7l42.7 0C592.2 192 640 239.8 640 298.7c0 11.8-9.6 21.3-21.3 21.3l-213.3 0zM224 224a96 96 0 1 1 192 0 96 96 0 1 1 -192 0zM128 485.3C128 411.7 187.7 352 261.3 352l117.3 0C452.3 352 512 411.7 512 485.3c0 14.7-11.9 26.7-26.7 26.7l-330.7 0c-14.7 0-26.7-11.9-26.7-26.7z\"/></svg>"
    }

    const colors = {
        "centralVaihingen": "",
        "centralStadmitte": "",
        "fachgruppe": ""
    }

    const fachgruppen = data.fachgruppen.filter(fg => selectedStudyPrograms.find(selectedStudyProgramm => fg.studyPrograms.indexOf(selectedStudyProgramm) !== -1))
    const fachgruppeInfoCardEl = document.getElementById("fachgruppe-info-card")
    const fachgruppeInfoContentEl = document.getElementById("fachgruppe-info-content")
    const fachgruppeInfoText = fachgruppen.map(fg => translate(fg.welcomeText)).join("")
    if (fachgruppeInfoText.length === 0) {
        fachgruppeInfoCardEl.style.display = "none"
    } else {
        fachgruppeInfoCardEl.style.display = "block"
        fachgruppeInfoContentEl.innerHTML = fachgruppeInfoText
    }


    const eliminations = fachgruppen.flatMap(fg => fg.events.map(event => event.eliminates).filter(elimination => elimination))

    const events = [...data.centralEvents
        .filter(event => !event.campusExclusive || fachgruppen.length === 0 || fachgruppen.find(fg => event.campusExclusive === fg.campus))
        .filter(event => !event || eliminations.indexOf(event.id) === -1)]
    events.push(...fachgruppen.flatMap(fg => fg.events.filter(event => !event.studyPrograms || selectedStudyPrograms.find(selectedStudyProgramm => event.studyPrograms.indexOf(selectedStudyProgramm) !== -1))))

    const paddingY = 2;
    const paddingX = 5;
    const marginY = 50
    const cellHeight = 70
    const cellWidth = 280

    const getColorClass = (event) => {
        if (fachgruppen.find(fg => fg.events.indexOf(event) !== -1)) {
            return "event-fachgruppe"
        } else if (event.locationShort.indexOf("Vaihingen") !== -1) {
            if (event.type === "info") {
                return "event-central-vaihingen-info"
            } else {
                return "event-central-vaihingen-social"
            }
        } else {
            if (event.type === "info") {
                return "event-central-stadtmitte-info"
            } else {
                return "event-central-stadtmitte-social"
            }
        }
    }


    const eventsByDay = Array.from({length: calendarOptions.lastDay - calendarOptions.firstDay + 1}, () => [])
    for (const event of events) {
        const startTime = event.startTime.split(":")
        const endTime = event.endTime.split(":")
        const start = parseInt(startTime[0]) - calendarOptions.startHour + parseInt(startTime[1]) / 60
        let end = parseInt(endTime[0]) - calendarOptions.startHour + parseInt(endTime[1]) / 60
        if (end < start) {
            end += 24
        }
        end = Math.max(end, start + 1)
        eventsByDay[event.day - calendarOptions.firstDay].push({event, times: {start, end}})
    }

    const eventsByDaysLayouted = []
    for (const eventsOfDay of eventsByDay) {
        const dayColumns = []

        while (eventsOfDay.length > 0) {
            const currentColumn = []
            dayColumns.push(currentColumn)
            for (let eventIndex = 0; eventIndex < eventsOfDay.length;) {
                const {event, times} = eventsOfDay[eventIndex]
                let overlap = false
                for (const {event: otherEvent, times: otherTimes} of currentColumn) {
                    if (event === otherEvent) continue
                    if (times.start < otherTimes.end && times.end > otherTimes.start) {
                        overlap = true
                        break
                    }
                }
                if (overlap) {
                    eventIndex++
                } else {
                    currentColumn.push({event, times})
                    eventsOfDay.splice(eventIndex, 1)
                }
            }
        }

        for (let columnIndex = dayColumns.length - 1; columnIndex >= 0; columnIndex--) {
            for (let event of dayColumns[columnIndex]) {
                let countParallel = columnIndex
                if (columnIndex + 1 < dayColumns.length) {
                    for (let otherEvent of dayColumns[columnIndex + 1]) {
                        if (event.times.start < otherEvent.times.end && event.times.end > otherEvent.times.start) {
                            countParallel = Math.max(countParallel, otherEvent.countParallel)
                        }
                    }
                }
                event.countParallel = countParallel
            }
        }
        const eventsOfDayLayouted = []
        for (let columnIndex = 0; columnIndex < dayColumns.length; columnIndex++) {
            for (let event of dayColumns[columnIndex]) {
                const width = (cellWidth - paddingX) / (event.countParallel + 1);
                let roundBorderBottomOff = false
                if (event.times.end > (calendarOptions.endHour - calendarOptions.startHour + 1)) {
                    event.times.end = calendarOptions.endHour - calendarOptions.startHour + 1
                    roundBorderBottomOff = true
                }
                event.bounds = {
                    left: columnIndex * width + paddingX,
                    width: width - paddingX,
                    top: marginY + event.times.start * cellHeight + paddingY,
                    height: (event.times.end - event.times.start) * cellHeight - (roundBorderBottomOff ? 1 : 2) * paddingY,
                    roundBorderBottomOff
                }
                eventsOfDayLayouted.push(event)
            }
        }
        eventsByDaysLayouted.push(eventsOfDayLayouted)
    }

    const buildEventLink = (event) => {
        const isCentral = !!data.centralEvents.find(ce => ce === event)

        let organizer
        if (isCentral) {
            organizer = "central"
        } else {
            const fg = fachgruppen.find(fg => fg.events.find(e => e === event))
            organizer = fg.name
        }
        return "#" + encodeURIComponent(`${encodeURIComponent(organizer)}&${encodeURIComponent(event.title.de || event.title)}&${encodeURIComponent(event.locationShort)}`)
    }

    const calendarHtml = `
        <div class="calendar-times">
            ${Array.from({length: calendarOptions.endHour - calendarOptions.startHour + 1}, (_, i) => i + calendarOptions.startHour).map(hour => `<div class="calendar-time">${hour.toString().padStart(2, '0')}:00</div>`).join("")}
        </div>
        
        ${Array.from({length: calendarOptions.lastDay - calendarOptions.firstDay + 1}, (_, i) => i + calendarOptions.firstDay).map(day => `
            <div class="calendar-day-column">
                <div class="calendar-day">
                    <div class="calendar-day-name">${new Date(calendarOptions.year, calendarOptions.month - 1, day).toLocaleDateString("de", {weekday: "long"})}</div>
                    <div class="calendar-day-date">${day.toString().padStart(2, '0')}.${calendarOptions.month.toString().padStart(2, '0')}.</div>
                </div>
                ${Array.from({length: calendarOptions.endHour - calendarOptions.startHour + 1}).map(() => `<div class="calendar-cell"></div>`).join("")}
                ${eventsByDaysLayouted[day - calendarOptions.firstDay].map(({event, bounds}) => `
                  <a class="calendar-event ${getColorClass(event)}" style="left: ${bounds.left}px; width: ${bounds.width}px; top: ${bounds.top}px; height: ${bounds.height}px;${bounds.roundBorderBottomOff ? 'border-bottom-left-radius: 0px;border-bottom-right-radius: 0px;' : ''}" href="${buildEventLink(event)}">
                    <div class="calendar-event-title">
                        <div class="calendar-event-title-text">
                          ${event.important ? `
                          <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 128 512"><!--!Font Awesome Free 6.6.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2024 Fonticons, Inc.--><path fill="currentColor" d="M96 64c0-17.7-14.3-32-32-32S32 46.3 32 64l0 256c0 17.7 14.3 32 32 32s32-14.3 32-32L96 64zM64 480a40 40 0 1 0 0-80 40 40 0 1 0 0 80z"/></svg>
                          ` : ''}
                          ${translate(event.title)}
                        </div>
                        <div class="calendar-event-type">
                            ${typeSvgs[event.type]}
                        </div>
                    </div>
                    <div class="calendar-event-time">
                      ${event.startTime} - ${event.endTime}
                    </div>
                    <div class="calendar-event-info">
                      <div class="calendar-event-location">
                        ${event.locationShort}
                        <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 384 512"><!--!Font Awesome Free 6.6.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free Copyright 2024 Fonticons, Inc.--><path fill="currentColor" d="M215.7 499.2C267 435 384 279.4 384 192C384 86 298 0 192 0S0 86 0 192c0 87.4 117 243 168.3 307.2c12.3 15.3 35.1 15.3 47.4 0zM192 128a64 64 0 1 1 0 128 64 64 0 1 1 0-128z"/></svg>
                      </div>
                    </div>
                  </a>
                `).join("")}
            </div>
        `).join("")}
    `
    calendarEl.innerHTML = calendarHtml

}


window.addEventListener("load", async () => {
    setupStudyProgramDropdown()
})

class FaqItem extends HTMLElement {
    static observedAttributes = ["question"];

    constructor() {
        super();
    }

    connectedCallback() {
        // Create a shadow root
        const card = document.createElement("div");
        card.classList.add("card", "faq-card");
        const cardHeader = document.createElement("header");
        cardHeader.className = "card-header";
        const cardHeaderTitle = document.createElement("p");
        cardHeaderTitle.className = "card-header-title";
        cardHeaderTitle.innerHTML = this.getAttribute("question");
        cardHeader.append(cardHeaderTitle);
        const cardHeaderButton = document.createElement("div");
        cardHeaderButton.className = "card-header-icon";
        cardHeaderButton.innerHTML = `<span class="icon"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512" style="width: 14px"><path fill="currentColor" d="M201.4 374.6c12.5 12.5 32.8 12.5 45.3 0l160-160c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L224 306.7 86.6 169.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l160 160z"/></svg></span>`;
        cardHeader.addEventListener("click", () => {
            card.classList.toggle("is-open")
        })
        cardHeader.append(cardHeaderButton);
        card.append(cardHeader);
        const cardContent = document.createElement("div");
        cardContent.className = "card-content";
        const content = document.createElement("div");
        content.className = "content";
        content.innerHTML = this.innerHTML
        this.innerHTML = ""
        cardContent.append(content);
        card.append(cardContent);
        this.append(card)
    }
}

customElements.define("faq-item", FaqItem);