const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require("mini-css-extract-plugin");
const ImageMinimizerPlugin = require("image-minimizer-webpack-plugin");
const { PurgeCSSPlugin } = require("purgecss-webpack-plugin");
const devMode = process.env.NODE_ENV !== "production";


module.exports = {

    entry: {
        index: ['./src/main.js'],
    },

    devServer: {
        port: 8080,
    },
    optimization: {
        splitChunks: {
            cacheGroups: {
                styles: {
                    name: "styles",
                    test: /\.css$/,
                    chunks: "all",
                    enforce: true,
                },
            },
        },
    },
    module: {
        rules: [
            {
                test: /\.css$/,
                use: [MiniCssExtractPlugin.loader, "css-loader"],
            },
            {
                test: /\.(html)$/,
                use: {
                    loader: 'html-loader'
                }
            },
            {
                test: /\.(png|jpe?g)$/i,
                use: [{
                    loader: ImageMinimizerPlugin.loader,
                    options: {
                        minimizer: {
                            implementation: ImageMinimizerPlugin.sharpMinify,
                        },
                        generator: [
                            {
                                preset: "webp",
                                implementation: ImageMinimizerPlugin.sharpGenerate,
                                options: {
                                    encodeOptions: {
                                        webp: {
                                            quality: 90,
                                        },
                                    },
                                },
                            },
                        ],
                    },
                }]
            },
        ],
    },
    output: {
        publicPath: '',
        filename: "[name].js"
    },

    plugins: [
        new MiniCssExtractPlugin({
            filename: devMode ? "[name].css" : "[name].[contenthash].css",
            chunkFilename: devMode ? "[id].css" : "[id].[contenthash].css",
        }),
        new HtmlWebpackPlugin({
            template: './src/index.html',
            filename: 'index.html',
            chunks: ['index'],
            inlineSource: '.(js|css)$'
        }),
        new PurgeCSSPlugin({
            paths: ["src/index.html", "src/main.js"],
        }),
        //new HtmlWebpackInlineSourcePlugin(HtmlWebpackPlugin)
    ]
};
